@@ -1,6 +1,7 @@
 BEGIN { 
     use lib qw{ . } ;
     use ExtUtils::testlib ;
+    use Cwd ;
     
     if ($EPSESSIONCLASS = $ENV{EMBPERL_SESSION_CLASS})
         {
@@ -8,6 +9,14 @@ BEGIN {
         die $@ if ($@) ;
         eval " use Apache\:\:Session\:\:$EPSESSIONCLASS; " ;
         }
+
+    my $cwd       = $ENV{EMBPERL_SRC} ;
+    my $i = 0 ;
+    foreach (@INC)
+        {
+        $INC[$i] = "$cwd/$_" if (/^(\.\/)?blib/) ;
+        $i++ ;
+        }
     } ;
 
 
